@@ -1,14 +1,13 @@
 #! /bin/sh
-# available as examples/math_test.sh
+# file: examples/math_test.sh
 
-testAdding()
-{
+testAdding() {
   result=`add_generic 1 2`
   assertEquals \
       "the result of '${result}' was wrong" \
       3 "${result}"
 
-  # disable non-generic tests
+  # Disable non-generic tests.
   [ -z "${BASH_VERSION:-}" ] && startSkipping
 
   result=`add_bash 1 2`
@@ -17,11 +16,10 @@ testAdding()
       3 "${result}"
 }
 
-oneTimeSetUp()
-{
-  # load include to test
+oneTimeSetUp() {
+  # Load include to test.
   . ./math.inc
 }
 
-# load and run shUnit2
-. ../src/shell/shunit2
+# Load and run shUnit2.
+. ../shunit2
